@@ -716,8 +716,8 @@ static bool LzmaDec_DecodeToDic(CLzmaDec *p, uint32_t dicLimit,
           *status = LZMA_STATUS_NEEDS_MORE_INPUT;
           return true;
         }
-        if (p->tempBuf[0] != 0)
-          return false;
+        /* check first byte of the LZMA stream */
+        if (p->tempBuf[0] != 0) return false;
 
         LzmaDec_InitRc(p, p->tempBuf);
         p->tempBufSize = 0;
