@@ -1,5 +1,5 @@
 /* Pdlzip - LZMA lossless data compressor
-   Copyright (C) 2010-2024 Antonio Diaz Diaz.
+   Copyright (C) 2010-2025 Antonio Diaz Diaz.
 
    This program is free software. Redistribution and use in source and
    binary forms, with or without modification, are permitted provided
@@ -188,11 +188,22 @@ static inline void Lt_set_member_size( Lzip_trailer data, unsigned long long sz
   { int i; for( i = 12; i <= 19; ++i ) { data[i] = (uint8_t)sz; sz >>= 8; } }
 
 
+typedef struct Cl_options	/* command-line options */
+  {
+  bool ignore_trailing;
+  bool loose_trailing;
+  } Cl_options;
+
+static inline void Cl_options_init( Cl_options * cl_opts )
+  { cl_opts->ignore_trailing = true; cl_opts->loose_trailing = false; }
+
+
 static inline void set_retval( int * retval, const int new_val )
   { if( *retval < new_val ) *retval = new_val; }
 
-static const char * const trailing_msg = "Trailing data not allowed.";
+static const char * const empty_msg = "Empty member not allowed.";
 static const char * const mem_msg = "Not enough memory.";
+static const char * const trailing_msg = "Trailing data not allowed.";
 
 /* defined in main.c */
 extern int verbosity;
